package com.ruoyi.device.mapper;

import java.util.List;
import org.springframework.stereotype.Repository;
import com.ruoyi.device.domain.RecordUse;

/**
 * 使用记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-19
 */
@Repository
public interface RecordUseMapper 
{
    /**
     * 查询使用记录
     * 
     * @param objId 使用记录主键
     * @return 使用记录
     */
    public RecordUse selectRecordUseByObjId(Long objId);

    /**
     * 查询使用记录列表
     * 
     * @param recordUse 使用记录
     * @return 使用记录集合
     */
    public List<RecordUse> selectRecordUseList(RecordUse recordUse);

    /**
     * 新增使用记录
     * 
     * @param recordUse 使用记录
     * @return 结果
     */
    public int insertRecordUse(RecordUse recordUse);

    /**
     * 修改使用记录
     * 
     * @param recordUse 使用记录
     * @return 结果
     */
    public int updateRecordUse(RecordUse recordUse);

    /**
     * 删除使用记录
     * 
     * @param objId 使用记录主键
     * @return 结果
     */
    public int deleteRecordUseByObjId(Long objId);

    /**
     * 批量删除使用记录
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordUseByObjIds(String[] objIds);
}
